/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Figure A2: INDUSTRY PRE-TRENDS.

The figure presents residual plots of the relationship between the adjusted penetration
of robots for 1993-2007 and the 1970-1990 change in log wage bill, log wage bill 
for produciton workers, log employment and log employment for production workers.

5.26.2018
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

****************************************
*** Load programs to produce figures ***
****************************************
cap program drop resid_plot
program define resid_plot, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) xtitle(string) ytitle(string)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	
	quietly: reg `y_vars' `x_var' `controls'  `wt'  `if', r
	local best=floor(1000*_b[`x_var'])/1000
	local serror=floor(1000*_se[`x_var'])/1000
	tempvar est_sample
	tempvar residual_y
	tempvar projected_y
	quietly: gen `est_sample'=e(sample)
	quietly: predict `residual_y' if `est_sample'==1, resid
	quietly: sum `y_vars' if e(sample) `wt'
	quietly: gen `projected_y'=`residual_y'+r(mean)
	quietly: sum `x_var' if e(sample) `wt'
	quietly: replace `projected_y'=`projected_y'+_b[`x_var']*(`x_var'-r(mean))
	tempvar projected_y_nocar
	quietly: gen `projected_y_nocar'=`projected_y' if industry!="automotive"
	
	*Define set of markers to label*
	tempvar tag_label
	tempvar tag_rank
	quietly: gen `tag_label'=0
	
	*Residuals*
	quietly: egen `tag_rank'=rank(`residual_y') if `residual_y'!=.
	quietly: sum `residual_y' if `tag_rank'==2
	quietly: replace `tag_label'=1 if `residual_y'<r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`residual_y') if `residual_y'!=.
	quietly: sum `residual_y' if `tag_rank'==2
	quietly: replace `tag_label'=1 if `residual_y'>r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	*Yvar*
	quietly: egen `tag_rank'=rank(`y_vars') if `residual_y'!=.
	quietly: sum `y_vars' if `tag_rank'==2
	quietly: replace `tag_label'=1 if `y_vars'<r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`y_vars') if `residual_y'!=.
	quietly: sum `y_vars' if `tag_rank'==2
	quietly: replace `tag_label'=1 if `y_vars'>r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	*Xvar*
	quietly: egen `tag_rank'=rank(`x_var') if `residual_y'!=.
	quietly: sum `x_var' if `tag_rank'==5
	quietly: replace `tag_label'=1 if `x_var'<r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`x_var') if `residual_y'!=.
	quietly: sum `x_var' if `tag_rank'==5
	quietly: replace `tag_label'=1 if `x_var'>r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: sum `x_var' `if', d
	local min=5*floor(r(min)/5)
	local max=5*floor(r(max)/5)+5
	
	quietly: sum `projected_y' `if'
	local miny=10*floor(r(min)/10)-10
	local maxy=10*floor(r(max)/10)+20
	
	twoway (scatter `projected_y' `x_var' `wt' if `projected_y'!=., mcolor("${main_color}") msize(medium) msymbol(circle) mlcolor(black) mlwidth(vthin)) ///
		   (lfit    `projected_y' `x_var' `wt' if `projected_y'!=., range(`min' `max') lcolor(gs4) lwidth(thin)) ///
		   (lfit    `projected_y_nocar' `x_var' `wt' if `projected_y'!=., range(`min' `max') lpattern(dash) lcolor(navy) lwidth(thin)) ///
		   (scatter `projected_y' `x_var' if `tag_label'==1, mcolor("${main_color}") msize(zero) mlabel(indname) mlabsize(vsmall) mlabcolor(gs8) mlabposition(12) mlabgap(small)), ///
		   note("b=`best' (se=`serror')", size(medlarge) position(5) ring(0) nobox ) legend(off) xtitle("`xtitle'", size(small)) ytitle("`ytitle'", size(small)) ///
		   ysize(5) xsize(8) ylabel(`miny'(10)`maxy', labsize(small) grid glwidth(thin) glcolor(white)) xlabel(`min'(5)`max', labsize(small) grid glwidth(thin) glcolor(white))  graphregion(fcolor(white) ifcolor(white)  lcolor(white) ilcolor(white)) plotregion(fcolor(white))

		   

end

use "${project}/clean_data/industry_data_ifr19", clear
gen change_robots=apr_${indmes}93_07
gen change_china=china_sag_iv_1991_2007

************************************
*Change in log Wage bill, 1970-1990*
*          Top-left				   *	
************************************
cap drop depvar
gen depvar=100*(ln(nber_pay1990)-ln(nber_pay1970))*14/20 /*For comparability with 1993-2007 results, converted to a 14-year change*/
reg depvar change_robots [w=nber_emp1970]
reg depvar change_robots change_china light_manuf [w=nber_emp1970]
resid_plot depvar change_robots [w=nber_emp1970], control(change_china light_manuf) xtitle("Adjusted penetration of robots 1993-2007") ytitle("Change in log wage bill 1970-1990")
graph export "$project/results/figure_industry_pay_placebo.png", as(png)  width(3000) replace


**********************************************************
*Change in log Wage bill of production workers, 1970-1990*
*					Top-right						     *
**********************************************************
cap drop depvar
gen depvar=100*(ln(nber_payblue1990)-ln(nber_payblue1970))*14/20 /*For comparability with 1993-2007 results, converted to a 14-year change*/
reg depvar change_robots [w=nber_emp1970]
reg depvar change_robots change_china light_manuf [w=nber_emp1970]
resid_plot depvar change_robots [w=nber_emp1970], control(change_china light_manuf) xtitle("Adjusted penetration of robots 1993-2007") ytitle("Change in log production wage bill 1970-1990")
graph export "$project/results/figure_industry_payblue_placebo.png", as(png)  width(3000)  replace


*************************************
*Change in log Employment 1970-1990 *
*			Bottom-Left				*
*************************************
cap drop depvar
gen depvar=100*(ln(nber_emp1990)-ln(nber_emp1970))*14/20 /*For comparability with 1993-2007 results, converted to a 14-year change*/
reg depvar change_robots [w=nber_emp1970]
reg depvar change_robots change_china light_manuf [w=nber_emp1970]
resid_plot depvar change_robots [w=nber_emp1970], control(change_china light_manuf) xtitle("Adjusted penetration of robots 1993-2007") ytitle("Change in log employment 1970-1990")
graph export "$project/results/figure_industry_emp_placebo.png", as(png)  width(3000) replace


************************************************
*Change in log Production employment, 1970-1990*
*				Bottom-Right				*
************************************************
cap drop depvar
gen depvar=100*(ln(nber_prode1990)-ln(nber_prode1970))*14/20 /*For comparability with 1993-2007 results, converted to a 14-year change*/
reg depvar change_robots [w=nber_emp1970]
reg depvar change_robots change_china light_manuf [w=nber_emp1970]
resid_plot depvar change_robots [w=nber_emp1970], control(change_china light_manuf) xtitle("Adjusted penetration of robots 1993-2007") ytitle("Change in log production employment 1970-1990")
graph export "$project/results/figure_industry_prode_placebo.png", as(png)  width(3000)  replace

