/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces estimates for:

Table A9  : "SUMMARY STATISTICS: COMMUTING ZONE DATA"
Sample means for all the commuting zones and by quartiles of exposure to robots.

Table A10: "RELATIONSHIP BETWEEN EXPOSURE TO ROBOTS AND COVARIATES" 
The table presents the relationship between the covariates used in our analysis
and exposure to robots, exposure to robots in the automotive industry, and exposure
to robots in other industries for 1993 - 2007.

5.21.2018 (Revised 4/9/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

* Dataset with outocome variables
use  "${project}/clean_data/outcomes_longdif_group.dta", clear

* Obtain compositionally adjusted wage change by commuting zone *
collapse (mean) base_wage_cz d_hrwage_ln_1990_2008 d_wkwage_ln_1990_2008 [w=wage_earners_1990], by(czone)

* Merge outcomes *
merge 1:1 czone using "${project}/clean_data/outcomes_longdif_czone.dta", assert(3) nogenerate

* Merge exposure and covariates in 1990 *
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

* Create quartiles of exposure to robots 
_pctile expof_${expomes}93_07 , p(25 50 75)
gen group=""
replace group="Q1. Lowest quartile" if (expof_${expomes}93_07<=r(r1))
replace group="Q2. Second quartile" if (expof_${expomes}93_07>r(r1) & expof_${expomes}93_07<=r(r2))
replace group="Q3. Third quartile" 	if (expof_${expomes}93_07>r(r2) & expof_${expomes}93_07<=r(r3))
replace group="Q4. Top quartile" 	if (expof_${expomes}93_07>r(r3) )
tab group


*Compute female share of manufacturing employment and share of light manufacturing WITHIN manufacturing *
replace ind_share_manufacturing_f_1990=ind_share_manufacturing_f_1990/ind_share_manufacturing_1990
replace ind_share_light_manuf_1990=ind_share_light_manuf_1990/ind_share_manufacturing_1990

*Re-scale variables *
foreach var of varlist base_*{
replace `var'=`var'/100
}

*Generate census division dummies*
tab division, gen(dum_div)

*Standardize exposure to robots*
sum expof_${expomes}93_07 [w=ipums_pop_1990]
gen s_exposure=(expof_${expomes}93_07-r(mean))/r(sd)

********************************************************************************
****** Columns 6 and 7 of Table A9: CORRELATIONS with Exposure to Robots *******
********************************************************************************

foreach var in d_emppriv_1990_2008 d_hrwage_ln_1990_2008   base_emppriv base_wage_cz  $demographics $industry_shares $other_shocks{
* Column 6: Raw Correlation
correlate `var' expof_${expomes}93_07 [w=ipums_pop_1990]
if "`var'"!="ind_share_manufacturing_1990"{
* Column 7: Correlation condiitonal on share of manufacturing and census divisions
pcorr  `var' expof_${expomes}93_07  ind_share_manufacturing_1990 dum_div* [w=ipums_pop_1990]
}
}


*************************************************************************************************
****** Columns 1 -5 of Table A9: Total Means and Means by Quartile of Exposure to Robots ********
*************************************************************************************************

* Columns 2 - 5: Means by quartiles of exposure to robots
preserve
collapse (mean)  base_wage_cz d_hrwage_ln_1990_2008  d*_emppriv_1990_2008 base_emppriv $demographics $industry_shares $other_shocks [w=ipums_pop_1990], by(group)
tempfile averages
save `averages', replace
restore

* Column  1: Overall means across all commuting zones
collapse (mean)  base_wage_cz d_hrwage_ln_1990_2008  d*_emppriv_1990_2008 base_emppriv $demographics $industry_shares $other_shocks [w=ipums_pop_1990]
gen group="All commuting zones"
append using `averages'
order group d*_emppriv_1990_2008  d_hrwage_ln_1990_2008  base_emppriv base_wage_cz  $demographics $industry_shares $other_shocks 

* Exports Columns 1 - 5 of Table A9
export excel using "${project}/results/table_descriptive_czone.xls", replace firstrow(variables)

********************************************************************************
****** Table A10 : Relationship between exposure to robots and covariates ******
********************************************************************************

* Dataset with outocome variables
use "${project}/clean_data/czones_exposure_longdif.dta", clear
* Bring in covariates
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

* Adjust college so that it refers to workers with AT MOST college *
replace ipums_college_1990=ipums_college_1990-ipums_masters_1990

* Standardize covariates*
foreach var of varlist $demographics $industry_shares $other_shocks  {
sum `var' [w=ipums_pop_1990]
replace `var'=(`var'-r(mean))/r(sd)
}

* Standardize outcomes *
sum expof_${expomes}93_07 [w=ipums_pop_1990]
replace expof_${expomes}93_07=(expof_${expomes}93_07-r(mean))/r(sd)

sum expoc_${expomes}93_07 [w=ipums_pop_1990]
replace expoc_${expomes}93_07=(expoc_${expomes}93_07-r(mean))/r(sd)

sum expon_${expomes}93_07 [w=ipums_pop_1990]
replace expon_${expomes}93_07=(expon_${expomes}93_07-r(mean))/r(sd)

*** Correlations between covariates and exposure to robots ***
* Column 1: Exposure to robots
reg expof_${expomes}93_07 $demographics $industry_shares $other_shocks [w=ipums_pop_1990], r cluster(state)
estimates store e1

* Column 3: Exposure to robots in automotive manufacturing
reg expoc_${expomes}93_07 $demographics $industry_shares $other_shocks [w=ipums_pop_1990], r cluster(state)
estimates store e2

* Column 5: Exposure to robots in other industries
reg expon_${expomes}93_07 $demographics $industry_shares $other_shocks [w=ipums_pop_1990], r cluster(state)
estimates store e3

*** Correlations between covariates and exposure to robots including regional dummies ***
* Column 2: Exposure to Robots
reg expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1b

* Column 4: Exposure to robots in automotive manufacturing
reg expoc_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e2b

* Column 6: Exposure to robots in other industries
reg expon_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e3b

*Export Table A10:
estout e1 e1b e2 e2b e3 e3b  using "$project/results/table_balance_covariates.tex", style(tex) ///
varlabels(ipums_female_1990 "Share female" ///
          ipums_hispanic_1990 "Share Hispanic" ///
		  ipums_white_1990 "Share White" ///
		  ipums_black_1990 "Share Black" ///
		  ipums_asian_1990 "Share Asian" ///
		  ipums_highschool_1990 "Share with no college" ///
		  ipums_college_1990 "Share with college degree" ///
		  ipums_masters_1990 "Share with masters degree" ///
		  ipums_above65_1990 "Share above 65 years of age" ///
		  ipums_logpop_1990 "Log population" ///
		  ind_share_manufacturing_1990 "Share employment in manufacturing" ///
		  ind_share_manufacturing_f_1990 "\multirow{2}{=}{Female share of manufacturing employment}" ///
		  ind_share_light_manuf_1990 "Share employment in light manufacturing" ///
		  chinashock_iv_90_07 "Exposure to Chinese imports" ///
		  expo_share_occ_routine_1990  "Share employment in routine jobs" ///
           ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none)  ///
keep($demographics $industry_shares $other_shocks ) ///
order($demographics $industry_shares $other_shocks) 
