/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A12 : "COEFFICIENTS FOR THE MAIN COVARIATES IN TABLES 2 AND 3"

The table reports the coefficients for the main covariates used in our analysis 
for models explaining changes in employment and wages.

5.21.2018 (Revised 4/9/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

********************************************************************************
*** Panel A: Long differences, 1990 - 2007									 ***
********************************************************************************

**** Columns 1 - 3: Change in the employment to population ratio  ***
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

* Column 1: Weighted by Population
reg d_emppriv_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1

* Column 2: Excludes zones with highest exposure 
reg d_emppriv_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2

* Column 3: Same weight to all czones
reg d_emppriv_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3

**** Columns 4 - 6: Change in Log hourly Wages  ***
use czone d_hrwage_ln_1990_2008 nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}93_07 $other_shocks )
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

encode state, gen(stcode)
encode group, gen(group_id)

* Column 4: Weighted by Population
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e4

* Column 5: Excludes zones with highest exposure
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if tag_exposure==1, absorb(group_id) cluster(stcode)
estimates store e5

* Column 6: Same weight to all czones
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=nat_earners_weight_1990], absorb(group_id) cluster(stcode)
estimates store e6

*Export Table A12, Panel A*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_covariates_longdif.tex", style(tex) ///
varlabels(expof_${expomes}93_07 "Exposure to robots" ///
          ind_share_manufacturing_1990 "\multirow{2}{=}{Share manufacturing employment}" ///
		  ind_share_manufacturing_f_1990 "\multirow{2}{=}{Female share of manufacturing employment}" ///
		  ind_share_light_manuf_1990 "\multirow{2}{=}{Share light manufacturing employment}" ///
		  chinashock_iv_90_07 "\multirow{2}{=}{Exposure to Chinese imports}" ///
		  expo_share_occ_routine_1990 "\multirow{2}{=}{Share employment in routine jobs}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_07  $industry_shares $other_shocks) ///
order(expof_${expomes}93_07 $industry_shares $other_shocks) 

********************************************************************************
*** Panel B: Stacked differences, 1990 - 2000 and 2000 - 2007  				 ***
********************************************************************************

**** Columns 1 - 3: Change in the employment to population ratio  ***
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate

* Column 1: Weighted by Population
reg d_emppriv expof_${expomes} $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e1

* Column 2: Excludes zones with highest exposure 
reg d_emppriv expof_${expomes} $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2

* Column 3: Same weight to all czones
reg d_emppriv expof_${expomes} $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e3

**** Columns 4 - 6: Change in Log hourly Wages  ***
use czone d_hrwage_ln nat_earners_weight_1990 wage_earners_1990 group year using  "${project}/clean_data/outcomes_stacked_group.dta", clear 
merge m:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes} $other_shocks_stacked )
merge m:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate

encode state, gen(stcode)
encode group, gen(group_id)

* Column 4: Weighted by Population
reghdfe d_hrwage_ln expof_${expomes} $demographics_stacked $industry_shares_stacked $other_shocks_stacked  $region_effects i.year [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e4

* Column 5: Excludes zones with highest exposure
reghdfe d_hrwage_ln expof_${expomes} $demographics_stacked $industry_shares_stacked $other_shocks_stacked  $region_effects i.year [w=wage_earners_1990] if tag_exposure==1, absorb(group_id) cluster(stcode)
estimates store e5

* Column 6: Same weight to all czones
reghdfe d_hrwage_ln expof_${expomes} $demographics_stacked $industry_shares_stacked $other_shocks_stacked  $region_effects i.year [w=nat_earners_weight_1990], absorb(group_id) cluster(stcode)
estimates store e6

*Export Table A12, Panel B*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table_covariates_stacked.tex", style(tex) ///
varlabels(expof_${expomes} "Exposure to robots" ///
          ind_share_manufacturing "\multirow{2}{=}{Share manufacturing employment}" ///
		  ind_share_manufacturing_f "\multirow{2}{=}{Female share of manufacturing employment}" ///
		  ind_share_light_manuf "\multirow{2}{=}{Share light manufacturing employment}" ///
		  chinashock_iv "\multirow{2}{=}{Exposure to Chinese imports}" ///
		  expo_share_occ_routine "\multirow{2}{=}{Share employment in routine jobs}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes} $industry_shares_stacked $other_shocks_stacked) ///
order(expof_${expomes} $industry_shares_stacked $other_shocks_stacked) 



