/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A29: "THE EFFECTS OF ROBOTS ON EMPLOYMENT AND WAGES BY GENDER"

The table presents estimates of the effects of exposure to robots on employment,
wages and other outcomes by gender.

- Panel A: Change in the employment to population ratio
- Panel B: Change in log hourly wages
- Panel C: Change in manufacturing employment to population ratio
- Panel D: Change in non-participation rate

5.21.2018 (Revised 4/10/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

********************************************************************************
**					Panels A, C, D - Employment Outcomes			  		  **
********************************************************************************

/*
Loop over employment outcomes:
- emppriv : employment to population ratio
- empman  : employment to population ratio in manufacturing
- nonpart : non-participation rate
*/
foreach depvar in  emppriv empman nonpart {

******************** Columns 1 - 6 : Long Differences ************************

use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07

* Column 1 : MEN - Weighted by population
reg d_`depvar'_m_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1m

* Column 2 : MEN - Excluding zones with highest exposure
reg d_`depvar'_m_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2m

* Column 3 : MEN - Unweighted
reg d_`depvar'_m_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3m

* Column 4 : WOMEN - Weighted by population
reg d_`depvar'_f_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1f

* Column 5 : WOMEN - Excluding zones with highest exposure
reg d_`depvar'_f_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2f

* Column 6 : WOMEN - Unweighted
reg d_`depvar'_f_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3f

******************** Columns 7 - 12 : Stacked Differences ************************
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
xtset czone year, delta(10)
sort czone year

gen exposure_robots=expof_${expomes}

* Column 7 : MEN - Weighted by population
reg d_`depvar'_m exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e4m

* Column 8 : MEN - Excluding zones with highest exposure
reg d_`depvar'_m exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e5m

* Column 9 : MEN - Unweighted
reg d_`depvar'_m exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e6m

* Column 10 : WOMEN - Weighted by population
reg d_`depvar'_f exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e4f

* Column 11 : WOMEN - Weighted by population
reg d_`depvar'_f exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e5f

* Column 12 : WOMEN - Unweighted
reg d_`depvar'_f exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e6f

*Export Panels A, C and D of Table A29 separatedly*
estout e1m e2m e3m e1f e2f e3f e4m e5m e6m e4f e5f e6f using "$project/results/table_gender_`depvar'.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 
}


********************************************************************************
**						Panel B : Log hourly wages		  			  		  **
********************************************************************************

foreach depvar in hrwage_ln {

******************** Columns 1 - 6 : Long Differences ************************
use czone d_`depvar'_1990_2008 nat_earners_weight_1990 wage_earners_1990 group group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}93_07 $other_shocks)
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

split group, p("_")
rename group1 gender

encode state, gen(stcode)
encode group, gen(group_id)
gen detroit=(czone==11600)

gen exposure_robots=expof_${expomes}93_07

* Column 1 : MEN - Weighted by population
reghdfe d_`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if gender=="men", absorb(group_id) cluster(stcode)
estimates store e1m

* Column 2 : MEN - Excluding zones with highest exposure
reghdfe d_`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if tag_exposure==1 & gender=="men", absorb(group_id) cluster(stcode)
estimates store e2m

* Column 3 : MEN - Unweighted
reghdfe d_`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=nat_earners_weight_1990] if gender=="men", absorb(group_id) cluster(stcode)
estimates store e3m

* Column 4 : WOMEN - Weighted by population
reghdfe d_`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if gender=="women", absorb(group_id) cluster(stcode)
estimates store e1f

* Column 5 : WOMEN - Excluding zones with highest exposure
reghdfe d_`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if tag_exposure==1 & gender=="women", absorb(group_id) cluster(stcode)
estimates store e2f

* Column 6 : WOMEN - Unweighted
reghdfe d_`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=nat_earners_weight_1990] if gender=="women", absorb(group_id) cluster(stcode)
estimates store e3f

******************** Columns 7 - 12 : Stacked Differences ************************
set matsize 5000
use czone year d_`depvar'* nat_earners_weight_1990 wage_earners_1990 group group using  "${project}/clean_data/outcomes_stacked_group.dta", clear 
merge m:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes} $other_shocks_stacked)
merge m:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate

split group, p("_")
rename group1 gender

encode state, gen(stcode)
encode group, gen(group_id)

gen exposure_robots=expof_${expomes}

* Column 7 : MEN - Weighted by population
reghdfe d_`depvar' exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=wage_earners_1990] if gender=="men", absorb(i.group_id##i.year) cluster(stcode)
estimates store e4m

* Column 8 : MEN - Excluding zones with highest exposure
reghdfe d_`depvar' exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=wage_earners_1990] if tag_exposure==1 & gender=="men", absorb(i.group_id##i.year) cluster(stcode)
estimates store e5m

* Column 9 : MEN - Unweighted
reghdfe d_`depvar' exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=nat_earners_weight_1990] if gender=="men", absorb(i.group_id##i.year) cluster(stcode)
estimates store e6m

* Column 10 : WOMEN - Weighted by population
reghdfe d_`depvar' exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=wage_earners_1990] if gender=="women", absorb(i.group_id##i.year) cluster(stcode)
estimates store e4f

* Column 11 : WOMEN - Weighted by population
reghdfe d_`depvar' exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=wage_earners_1990] if tag_exposure==1 & gender=="women", absorb(i.group_id##i.year) cluster(stcode)
estimates store e5f

* Column 12 : WOMEN - Unweighted
reghdfe d_`depvar' exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=nat_earners_weight_1990] if gender=="women", absorb(i.group_id##i.year) cluster(stcode)
estimates store e6f


*Export Panel B of Table A29*
estout e1m e2m e3m e1f e2f e3f e4m e5m e6m e4f e5f e6f using "$project/results/table_gender_`depvar'.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 
}

