/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A5: "INDUSTRY-LEVEL RESULTS: DIFFERENT TIME PERIODS"

The table presents estimates of the relationship between adjusted penetration of
robots and changes in log wage bill and log employment across US industries over
the periods:
1993-2010, 2000-2010, 2004-2010, 2000-2007, 2004-2007

5.21.2018 (revised 4/1/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

***************** Panel A:   From 1993 to 2010        ********************
use "${project}/clean_data/industry_data_ifr19", clear

***Reduced-form***
gen change_robots=apr_${indmes}93_10
gen change_china=china_sag_iv_1991_2007

*Column 1: CBP change in log wage bill*
cap drop depvar
gen depvar=100*(ln(cbp_real_pay2010)-ln(cbp_real_pay1993))
reg depvar change_robots change_china manufacturing light_manuf [w=cbp_emp1993], r 
estimates store e1

*Column 2: NBER within manufacturing change in log wage bill*
cap drop depvar
gen depvar=100*(ln(nber_pay2010)-ln(nber_pay1993))
reg depvar change_robots change_china  light_manuf [w=nber_emp1993], r 
estimates store e2

*Column 3: NBER production workers within manufacturing change in log wage bill*
cap drop depvar
gen depvar=100*(ln(nber_payblue2010)-ln(nber_payblue1993))
reg depvar change_robots change_china  light_manuf [w=nber_emp1993], r 
estimates store e3

*Column 4: CBP change in log employment*
cap drop depvar
gen depvar=100*(ln(cbp_emp2010)-ln(cbp_emp1993))
reg depvar change_robots change_china manufacturing light_manuf [w=cbp_emp1993], r 
estimates store e4


*Column 5: NBER within manufacturing change in log employment*
cap drop depvar
gen depvar=100*(ln(nber_emp2010)-ln(nber_emp1993))
reg depvar change_robots change_china  light_manuf [w=nber_emp1993], r 
estimates store e5

*Column 6: NBER production workers within manufacturing change in log employment*
cap drop depvar
gen depvar=100*(ln(nber_prode2010)-ln(nber_prode1993))
reg depvar change_robots change_china  light_manuf [w=nber_emp1993], r 
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_appendix_industry_1993_2010.tex", style(tex) ///
varlabels(change_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ } "  change_china "\multirow{2}{=}{Chinese imports}" light_manuf "\multirow{2}{=}{Light manufacturing}" manufacturing "\multirow{2}{=}{Manufacturing}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_robots ) ///
order(change_robots )


***************** Panel B:   From 2000 to 2010        ********************
use "${project}/clean_data/industry_data_ifr19", clear

***Reduced-form***
gen change_robots=apr_${indmes}00_10
gen change_china=china_sag_iv_1999_2007

*Column 1: CBP change in log wage bill*
cap drop depvar
gen depvar=100*(ln(cbp_real_pay2010)-ln(cbp_real_pay2000))
reg depvar change_robots change_china manufacturing light_manuf [w=cbp_emp2000], r 
estimates store e1

*Column 2: NBER within manufacturing change in log wage bill*
cap drop depvar
gen depvar=100*(ln(nber_pay2010)-ln(nber_pay2000))
reg depvar change_robots change_china  light_manuf [w=nber_emp2000], r 
estimates store e2

*Column 3: NBER production workers within manufacturing change in log wage bill*
cap drop depvar
gen depvar=100*(ln(nber_payblue2010)-ln(nber_payblue2000))
reg depvar change_robots change_china  light_manuf [w=nber_emp2000], r 
estimates store e3

*Column 4: CBP change in log employment*
cap drop depvar
gen depvar=100*(ln(cbp_emp2010)-ln(cbp_emp2000))
reg depvar change_robots change_china manufacturing light_manuf [w=cbp_emp2000], r 
estimates store e4


*Column 5: NBER within manufacturing change in log employment*
cap drop depvar
gen depvar=100*(ln(nber_emp2010)-ln(nber_emp2000))
reg depvar change_robots change_china  light_manuf [w=nber_emp2000], r 
estimates store e5

*Column 6: NBER production workers within manufacturing change in log employment*
cap drop depvar
gen depvar=100*(ln(nber_prode2010)-ln(nber_prode2000))
reg depvar change_robots change_china  light_manuf [w=nber_emp2000], r 
estimates store e6


*Export tables*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_appendix_industry_2000_2010.tex", style(tex) ///
varlabels(change_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ } "  change_china "\multirow{2}{=}{Chinese imports}" light_manuf "\multirow{2}{=}{Light manufacturing}" manufacturing "\multirow{2}{=}{Manufacturing}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_robots ) ///
order(change_robots )


***************** Panel C:   From 2004 to 2010        ********************
use "${project}/clean_data/industry_data_ifr19", clear

***Reduced-form***
gen change_robots=apr_${indmes}04_10
gen change_china=china_sag_iv_1999_2007

*Column 1: CBP change in log wage bill*
cap drop depvar
gen depvar=100*(ln(cbp_real_pay2010)-ln(cbp_real_pay2004))
reg depvar change_robots change_china manufacturing light_manuf [w=cbp_emp2004], r 
estimates store e1

*Column 2: NBER within manufacturing change in log wage bill*
cap drop depvar
gen depvar=100*(ln(nber_pay2010)-ln(nber_pay2004))
reg depvar change_robots change_china  light_manuf [w=nber_emp2004], r 
estimates store e2

*Column 3: NBER production workers within manufacturing change in log wage bill*
cap drop depvar
gen depvar=100*(ln(nber_payblue2010)-ln(nber_payblue2004))
reg depvar change_robots change_china  light_manuf [w=nber_emp2004], r 
estimates store e3

*Column 4: CBP change in log employment*
cap drop depvar
gen depvar=100*(ln(cbp_emp2010)-ln(cbp_emp2004))
reg depvar change_robots change_china manufacturing light_manuf [w=cbp_emp2004], r 
estimates store e4


*Column 5: NBER within manufacturing change in log employment*
cap drop depvar
gen depvar=100*(ln(nber_emp2010)-ln(nber_emp2004))
reg depvar change_robots change_china  light_manuf [w=nber_emp2004], r 
estimates store e5

*Column 6: NBER production workers within manufacturing change in log employment*
cap drop depvar
gen depvar=100*(ln(nber_prode2010)-ln(nber_prode2004))
reg depvar change_robots change_china  light_manuf [w=nber_emp2004], r 
estimates store e6


*Export tables*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_appendix_industry_2004_2010.tex", style(tex) ///
varlabels(change_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ } "  change_china "\multirow{2}{=}{Chinese imports}" light_manuf "\multirow{2}{=}{Light manufacturing}" manufacturing "\multirow{2}{=}{Manufacturing}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_robots ) ///
order(change_robots )


***************** Panel D:   From 2000 to 2007       ********************
use "${project}/clean_data/industry_data_ifr19", clear

***Reduced-form***
gen change_robots=apr_${indmes}00_07
gen change_china=china_sag_iv_1999_2007

*Column 1: CBP change in log wage bill*
cap drop depvar
gen depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay2000))
reg depvar change_robots change_china manufacturing light_manuf [w=cbp_emp2000], r 
estimates store e1


*Column 2: NBER within manufacturing change in log wage bill*
cap drop depvar
gen depvar=100*(ln(nber_pay2007)-ln(nber_pay2000))
reg depvar change_robots change_china  light_manuf [w=nber_emp2000], r 
estimates store e2

*Column 3: NBER production workers within manufacturing change in log wage bill*
cap drop depvar
gen depvar=100*(ln(nber_payblue2007)-ln(nber_payblue2000))
reg depvar change_robots change_china  light_manuf [w=nber_emp2000], r 
estimates store e3

*Column 4: CBP change in log employment*
cap drop depvar
gen depvar=100*(ln(cbp_emp2007)-ln(cbp_emp2000))
reg depvar change_robots change_china manufacturing light_manuf [w=cbp_emp2000], r 
estimates store e4

*Column 5: NBER within manufacturing change in log employment*
cap drop depvar
gen depvar=100*(ln(nber_emp2007)-ln(nber_emp2000))
reg depvar change_robots change_china  light_manuf [w=nber_emp2000], r 
estimates store e5

*Column 6: NBER production workers within manufacturing change in log employment*
cap drop depvar
gen depvar=100*(ln(nber_prode2007)-ln(nber_prode2000))
reg depvar change_robots change_china  light_manuf [w=nber_emp2000], r 
estimates store e6


*Export tables*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_appendix_industry_2000_2007.tex", style(tex) ///
varlabels(change_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ } "  change_china "\multirow{2}{=}{Chinese imports}" light_manuf "\multirow{2}{=}{Light manufacturing}" manufacturing "\multirow{2}{=}{Manufacturing}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_robots ) ///
order(change_robots )


***************** Panel E:   From 2004 to 2007        ********************
use "${project}/clean_data/industry_data_ifr19", clear

***Reduced-form***
gen change_robots=apr_${indmes}04_07
gen change_china=china_sag_iv_1999_2007

*Column 1: CBP change in log wage bill*
cap drop depvar
gen depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay2004))
reg depvar change_robots change_china manufacturing light_manuf [w=cbp_emp2004], r 
estimates store e1

*Column 2: NBER within manufacturing change in log wage bill*
cap drop depvar
gen depvar=100*(ln(nber_pay2007)-ln(nber_pay2004))
reg depvar change_robots change_china  light_manuf [w=nber_emp2004], r 
estimates store e2

*Column 3: NBER production workers within manufacturing change in log wage bill*
cap drop depvar
gen depvar=100*(ln(nber_payblue2007)-ln(nber_payblue2004))
reg depvar change_robots change_china  light_manuf [w=nber_emp2004], r 
estimates store e3

*Column 4: CBP change in log employment*
cap drop depvar
gen depvar=100*(ln(cbp_emp2007)-ln(cbp_emp2004))
reg depvar change_robots change_china manufacturing light_manuf [w=cbp_emp2004], r 
estimates store e4


*Column 5: NBER within manufacturing change in log employment*
cap drop depvar
gen depvar=100*(ln(nber_emp2007)-ln(nber_emp2004))
reg depvar change_robots change_china  light_manuf [w=nber_emp2004], r 
estimates store e5

*Column 6: NBER production workers within manufacturing change in log employment*
cap drop depvar
gen depvar=100*(ln(nber_prode2007)-ln(nber_prode2004))
reg depvar change_robots change_china  light_manuf [w=nber_emp2004], r 
estimates store e6


*Export tables*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_appendix_industry_2004_2007.tex", style(tex) ///
varlabels(change_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ } "  change_china "\multirow{2}{=}{Chinese imports}" light_manuf "\multirow{2}{=}{Light manufacturing}" manufacturing "\multirow{2}{=}{Manufacturing}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_robots ) ///
order(change_robots )



