/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A4: "INDUSTRY-LEVEL RESULTS: DIFFERENT CONSTRUCTIONS OF THE ADJUSTED
		   PENETRATION OF ROBOTS"

The table presents estimates of the relationship between adjusted penetration of
robots and changes in log wage bill, log value added and labor share across US
industries using different constructions of the measure for adjusted penetration
of robots:

euro5_qo: Baseline instrument, robots penetration in Denmark, Finland, France, Italy and Sweden
euro6_qo: adds Germany to euro5_qo
euro9_qo: adds Germany, Norway, Spain and the UK to euro5_qo
euro5_lv: Robots penetration in Denmark, Finland, France, Italy and Sweden without 
		  without adjustment term (equation 12)
euro5_price: Robots penetration in Denmark, Finland, France, Italy and Sweden adjusted 
		     using available data on prices of robots


5.21.2018 (Revised 4/1/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */


foreach instrument_def in euro5_qo euro6_qo euro9_qo euro5_lv euro5_price{

***************    Columns 1 - 3 : Long Differences 1993 - 2007 ****************
use "${project}/clean_data/industry_data_ifr19", clear
gen change_robots=apr_`instrument_def'93_07
gen change_china=china_sag_iv_1991_2007

* Column 1: CBP (all industries) *
cap drop depvar
gen depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay1993))
reg depvar change_robots change_china manufacturing light_manuf [w=cbp_emp1993], r 
estimates store e1

* Column 2: NBER - within manufacturing*
cap drop depvar
gen depvar=100*(ln(nber_pay2007)-ln(nber_pay1993))
reg depvar change_robots change_china  light_manuf [w=nber_emp1993], r 
estimates store e2

* Column 3: NBER - production workers within manufacturing *
cap drop depvar
gen depvar=100*(ln(nber_payblue2007)-ln(nber_payblue1993))
reg depvar change_robots change_china  light_manuf [w=nber_emp1993], r 
estimates store e3

* Column 8 : BEA - IO Value added*
cap drop depvar
gen depvar=100*(ln(beaio_VA07)-ln(beaio_VA92))/15
reg depvar change_robots change_china manufacturing light_manuf [w=beaio_VA92], r 
estimates store e8

*Column 9: BEA - IO Labor share*
cap drop depvar
gen depvar=100*(beaio_labsh07-beaio_labsh92)
reg depvar change_robots change_china manufacturing light_manuf [w=beaio_VA92], r 
estimates store e9


**********    Columns 4 - 6: Stacked differences 1993 - 2000, 2000 - 2007 ******

use "${project}/clean_data/industry_data_ifr19", clear
encode industry_ifr, gen(indcode)
expand 2
bys industry_ifr: gen period=_n

*Robot exposure
bys industry_ifr: gen change_robots=apr_`instrument_def'00_07 if _n==2
bys industry_ifr: replace change_robots=apr_`instrument_def'93_00 if _n==1

*Chinese exposure
bys industry_ifr: gen change_china=china_sag_iv_1999_2007 if _n==2
bys industry_ifr: replace change_china=china_sag_iv_1991_1999 if _n==1

* Column 4: CBP (all industries) *
cap drop depvar
gen depvar=.
replace depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay2000)) if period==2
replace depvar=100*(ln(cbp_real_pay2000)-ln(cbp_real_pay1993)) if period==1
reg depvar change_robots change_china manufacturing light_manuf i.period [w=cbp_emp1993],  r cluster(indcode)
estimates store e4

* Column 5: CBP (all industries) + industry dummies*
reg depvar change_robots change_china i.indcode i.period [w=cbp_emp1993],  r cluster(indcode)
estimates store e5

* Column 6 : NBER  - within manufacturing*
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_pay2007)-ln(nber_pay2000)) if period==2
replace depvar=100*(ln(nber_pay2000)-ln(nber_pay1993)) if period==1
reg depvar change_robots change_china  light_manuf i.period [w=nber_emp1993],  r cluster(indcode)
estimates store e6

* Column 7: NBER - production workers within manufacturing *
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_payblue2007)-ln(nber_payblue2000)) if period==2
replace depvar=100*(ln(nber_payblue2000)-ln(nber_payblue1993)) if period==1
reg depvar change_robots change_china  light_manuf i.period [w=nber_emp1993], r 
estimates store e7

*Export tables*
estout e1 e2 e3 e4 e5 e6 e7 e8 e9 using "$project/results/table_industry_instrument_`instrument_def'.tex", style(tex) ///
varlabels(change_robots "\multirow{2}{=}{Adjusted penetration of robots, $ \overline{APR}_i $ } "  change_china "\multirow{2}{=}{Chinese imports}" light_manuf "\multirow{2}{=}{Light manufacturing}" manufacturing "\multirow{2}{=}{Manufacturing}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_robots ) ///
order(change_robots ) 
}
