/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A11 : "THE EFFECT OF ROBOTS ON EMPLOYMENT AND WAGES: EXCLUDES THE SHARE OF
			EMPLOYMENT IN LIGHT MANUFACTURING AND THE FEMALE SHARE OF MANUFACTURING
			EMPLOYMENT FROM COVARIATES"

The table presents estimates of the effects of exposure to robots on employment
to population ratios and log hourly wages. 
- Panel A: Change in the employment to population ratio: 
			Excludes share of employment in light manufacturing and female share of employment in manufacturing
- Panel B: Change in the employment to population ratio:
			Excludes the female share of employment in manufacturing
- Panel C: Change in log hourly wages:
			Excludes share of employment in light manufacturing and female share of employment in manufacturing
- Panel D: Change in log hourly wages:
			Excludes the female share of employment in manufacturing
			

5.21.2018 (Revised 4/9/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

********************************************************************************
*** Panel A: Change in the Employment to Population Ratio					 ***
*** Excluded covariates: Share of Employment in Light Manufacturing,		 ***
***						 Share of Female Employment in Manufacturing		 ***				
********************************************************************************

*******  Columns 1 - 3 : Long Differences 1990 - 2007	*******
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07

* Column 1: Weighted by Population
reg d_emppriv_1990_2008 exposure_robots $demographics ind_share_manufacturing_1990  $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1long

* Column 2: Excludes zones with highest exposure
reg d_emppriv_1990_2008 exposure_robots $demographics ind_share_manufacturing_1990  $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2long

* Column 3: Unweighted
reg d_emppriv_1990_2008 exposure_robots $demographics ind_share_manufacturing_1990  $other_shocks $region_effects, r cluster(state)
estimates store e3long

*******  Columns 4 - 6 : Stacked Differences 1990 - 2000 and 2000 - 2007 *******
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
xtset czone year, delta(10)
sort czone year

gen exposure_robots=expof_${expomes}

* Column 4: Weighted by Population
reg d_emppriv exposure_robots $demographics_stacked ind_share_manufacturing $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e1stack

* Column 5: Excludes zones with highest exposure
reg d_emppriv exposure_robots $demographics_stacked ind_share_manufacturing  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2stack

* Column 6: Unweighted
reg d_emppriv exposure_robots $demographics_stacked ind_share_manufacturing  $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e3stack

*** Export Panel A, Table A 11 ****
estout e1long e2long e3long  e1stack e2stack e3stack   using "$project/results/table_lightman_emppriv.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots)


********************************************************************************
*** Panel B: Change in the Employment to Population Ratio					 ***
*** Excluded covariates: Share of Female Employment in Manufacturing		 ***
********************************************************************************

*******  Columns 1 - 3 : Long Differences 1990 - 2007	*******
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07

* Column 1: Weighted by Population
reg d_emppriv_1990_2008 exposure_robots $demographics ind_share_manufacturing_1990 ind_share_light_manuf_1990 $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1long

* Column 2: Excludes zones with highest exposure
reg d_emppriv_1990_2008 exposure_robots $demographics ind_share_manufacturing_1990 ind_share_light_manuf_1990 $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2long

* Column 3: Unweighted
reg d_emppriv_1990_2008 exposure_robots $demographics ind_share_manufacturing_1990 ind_share_light_manuf_1990 $other_shocks $region_effects, r cluster(state)
estimates store e3long

*******  Columns 4 - 6 : Stacked Differences 1990 - 2000 and 2000 - 2007 *******
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
xtset czone year, delta(10)
sort czone year

gen exposure_robots=expof_${expomes}

* Column 4: Weighted by Population
reg d_emppriv exposure_robots $demographics_stacked ind_share_manufacturing ind_share_light_manuf $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e1stack

* Column 5: Excludes zones with highest exposure
reg d_emppriv exposure_robots $demographics_stacked ind_share_manufacturing ind_share_light_manuf $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2stack

* Column 6: Unweighted
reg d_emppriv exposure_robots $demographics_stacked ind_share_manufacturing ind_share_light_manuf $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e3stack

*** Export Panel B, Table A 11 ****
estout e1long e2long e3long  e1stack e2stack e3stack   using "$project/results/table_lightman_alt_emppriv.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots)


********************************************************************************
*** Panel C: Change in the Log Hourly Wages									 ***
*** Excluded covariates: Share of Employment in Light Manufacturing,		 ***
***						 Share of Female Employment in Manufacturing		 ***				
********************************************************************************

*******  Columns 1 - 3 : Long Differences 1990 - 2007	*******
use czone d_hrwage_ln_1990_2008 nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}93_07  $other_shocks)
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

gen exposure_robots=expof_${expomes}93_07

* Column 1: Weighted by Population
reghdfe d_hrwage_ln_1990_2008 exposure_robots $demographics ind_share_manufacturing_1990 $other_shocks $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e1long

* Column 2: Excludes zones with highest exposure
reghdfe d_hrwage_ln_1990_2008 exposure_robots $demographics ind_share_manufacturing_1990 $other_shocks $region_effects [w=wage_earners_1990] if tag_exposure==1, absorb(group_id) cluster(stcode)
estimates store e2long

* Column 3: Unweighted
reghdfe d_hrwage_ln_1990_2008 exposure_robots $demographics ind_share_manufacturing_1990 $other_shocks $region_effects [w=nat_earners_weight_1990], absorb(group_id) cluster(stcode)
estimates store e3long


*******  Columns 4 - 6 : Stacked Differences 1990 - 2000 and 2000 - 2007 *******
set matsize 5000
use czone year d_hrwage_ln* nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_stacked_group.dta", clear 
merge m:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}  $other_shocks_stacked)
merge m:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

gen exposure_robots=expof_${expomes}

* Column 4: Weighted by Population
reghdfe d_hrwage_ln exposure_robots $demographics_stacked ind_share_manufacturing $other_shocks_stacked $region_effects i.year [w=wage_earners_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e1stack

* Column 5: Excludes zones with highest exposure
reghdfe d_hrwage_ln exposure_robots $demographics_stacked ind_share_manufacturing $other_shocks_stacked $region_effects i.year [w=wage_earners_1990] if tag_exposure==1, absorb(i.group_id##i.year) cluster(stcode)
estimates store e2stack

* Column 6: Unweighted
reghdfe d_hrwage_ln exposure_robots $demographics_stacked ind_share_manufacturing $other_shocks_stacked $region_effects i.year [w=nat_earners_weight_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e3stack

*** Export Panel C, Table A 11 ****
estout e1long e2long e3long e1stack e2stack e3stack using "$project/results/table_lightman_hrwage_ln.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 

********************************************************************************
*** Panel D: Change in the Log Hourly Wages									 ***
*** Excluded covariates: Share of Female Employment in Manufacturing		 ***
********************************************************************************

*******  Columns 1 - 3 : Long Differences 1990 - 2007	*******
use czone d_hrwage_ln_1990_2008 nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}93_07  $other_shocks)
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

gen exposure_robots=expof_${expomes}93_07

* Column 1: Weighted by Population
reghdfe d_hrwage_ln_1990_2008 exposure_robots $demographics ind_share_manufacturing_1990 ind_share_light_manuf_1990 $other_shocks $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e1long

* Column 2: Excludes zones with highest exposure
reghdfe d_hrwage_ln_1990_2008 exposure_robots $demographics ind_share_manufacturing_1990 ind_share_light_manuf_1990 $other_shocks $region_effects [w=wage_earners_1990] if tag_exposure==1, absorb(group_id) cluster(stcode)
estimates store e2long

* Column 3: Unweighted
reghdfe d_hrwage_ln_1990_2008 exposure_robots $demographics ind_share_manufacturing_1990 ind_share_light_manuf_1990 $other_shocks $region_effects [w=nat_earners_weight_1990], absorb(group_id) cluster(stcode)
estimates store e3long

*******  Columns 4 - 6 : Stacked Differences 1990 - 2000 and 2000 - 2007 *******
set matsize 5000
use czone year d_hrwage_ln* nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_stacked_group.dta", clear 
merge m:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}  $other_shocks_stacked)
merge m:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

gen exposure_robots=expof_${expomes}

* Column 4: Weighted by Population
reghdfe d_hrwage_ln exposure_robots $demographics_stacked ind_share_manufacturing ind_share_light_manuf $other_shocks_stacked $region_effects i.year [w=wage_earners_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e1stack

* Column 5: Excludes zones with highest exposure
reghdfe d_hrwage_ln exposure_robots $demographics_stacked ind_share_manufacturing ind_share_light_manuf $other_shocks_stacked $region_effects i.year [w=wage_earners_1990] if tag_exposure==1, absorb(i.group_id##i.year) cluster(stcode)
estimates store e2stack

* Column 6: Unweighted
reghdfe d_hrwage_ln exposure_robots $demographics_stacked ind_share_manufacturing ind_share_light_manuf $other_shocks_stacked $region_effects i.year [w=nat_earners_weight_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e3stack

*** Export Panel D, Table A 11 ****
estout e1long e2long e3long e1stack e2stack e3stack using "$project/results/table_lightman_alt_hrwage_ln.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 

