/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Panels A, B, C and D of Table A18 : 
"THE EFFECTS OF ROBOTS ON MIGRATION, POPULATION, AND HOUSING PRICES AND RENTS."

The table presents estimates of the effects of exposure to robots on migration rates
and changes in log population
- Panel A: Net migration rate - excluse baseline population from covariates.
- Panel B: Net migration rate - control for baseline population.
- Panel C: Change in log population - exclude baseline population from covariates.
- Panel D: Change in log population - control for baseline population

5.21.2018 (Revised 4/9/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

* Create macro of covariates excluding population for panel A and C*
global demographics_nopop: subinstr global demographics "ipums_logpop_1990" "", all
global demographics_stacked_nopop: subinstr global demographics_stacked "ipums_logpop" "", all


*************************************************************
**Panel A and B: Dep. Variable is Net migration rate (IRS) **
*************************************************************

***** Columns 1 -3 : Long Differences, 1990 - 2007 *****
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07
gen logpop=ipums_logpop_1990

********    Panel A: Exclude baseline population from covariates     ***********

*Column 1 : Weighted by population
reg netmigration_90_07 exposure_robots $demographics_nopop $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1nop

*Column 2 : Exclude zones with highest exposure
reg netmigration_90_07 exposure_robots $demographics_nopop $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2nop

*Column 3 : Unweighted
reg netmigration_90_07 exposure_robots $demographics_nopop $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3nop

********    Panel B: Control for baseline population      ***********

*Column 1 : Weighted by population
reg netmigration_90_07 exposure_robots logpop $demographics_nopop $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1pop

*Column 2 : Exclude zones with highest exposure
reg netmigration_90_07 exposure_robots logpop $demographics_nopop $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2pop

*Column 3 : Unweighted
reg netmigration_90_07 exposure_robots logpop $demographics_nopop $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3pop

***** Columns 4 - 6 : Stacked Differences, 1990 - 2000 and 2000 - 2007 *****
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
xtset czone year, delta(10)
sort czone year

gen exposure_robots=expof_${expomes}
gen logpop=ipums_logpop

********    Panel A: Exclude baseline population from covariates     ***********

*Column 4: Weighted by population*
reg migration exposure_robots $demographics_stacked_nopop $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e4nop

*Column 5 : Exclude zones with highest exposure
reg migration exposure_robots $demographics_stacked_nopop $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e5nop

*Column 6 : Unweighted
reg migration exposure_robots $demographics_stacked_nopop $industry_shares_stacked  $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e6nop

********    Panel B: Control for baseline population      ***********

*Column 4: Weighted by population*
reg migration exposure_robots logpop $demographics_stacked_nopop $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e4pop

*Column 5 : Exclude zones with highest exposure
reg migration exposure_robots logpop $demographics_stacked_nopop $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e5pop

*Column 6 : Unweighted
reg migration exposure_robots logpop $demographics_stacked_nopop $industry_shares_stacked  $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e6pop


*Export table A18, Panel A*
estout e1nop e2nop e3nop e4nop e5nop e6nop using "$project/results/table_migration_nop.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots ) ///
order(exposure_robots ) 

*Export table A18, Panel B*
estout e1pop e2pop e3pop e4pop e5pop e6pop using "$project/results/table_migration_pop.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots" logpop "\multirow{2}{=}{Log of baseline population}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots logpop) ///
order(exposure_robots logpop) 


************************************************************
**Panel C and D: Dep. Variable is change in Log population**
************************************************************

***** Columns 1 -3 : Long Differences, 1990 - 2007 *****
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07
gen logpop=ipums_logpop_1990

********    Panel C: Exclude baseline population from covariates     ***********

*Column 1: Weighted by population*
reg d_logpop_1990_2008 exposure_robots $demographics_nopop $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1nop

*Column 2: Excludes zones with highest exposure*
reg d_logpop_1990_2008 exposure_robots $demographics_nopop $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2nop

*Column 3: Same weight to all czones*
reg d_logpop_1990_2008 exposure_robots $demographics_nopop $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3nop

********    Panel D: Control for baseline population      ***********

*Column 1: Weighted by population*
reg d_logpop_1990_2008 exposure_robots logpop $demographics_nopop $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1pop

*Column 2: Excludes zones with highest exposure*
reg d_logpop_1990_2008 exposure_robots logpop $demographics_nopop $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2pop

*Column 3: Same weight to all czones*
reg d_logpop_1990_2008 exposure_robots logpop $demographics_nopop $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3pop


***** Columns 4 - 6 : Stacked Differences, 1990 - 2000 and 2000 - 2007 *****
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate

* Set panel structure for stacked differences
xtset czone year, delta(10)
sort czone year

gen exposure_robots=expof_${expomes}
gen logpop=ipums_logpop

********    Panel C: Exclude baseline population from covariates     ***********

*Column 4: Weighted by population*
reg d_logpop exposure_robots $demographics_stacked_nopop $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e4nop

*Column 5: Excludes zones with highest exposure*
reg d_logpop exposure_robots $demographics_stacked_nopop $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e5nop

*Column 6: Same weight to all czones*
reg d_logpop exposure_robots $demographics_stacked_nopop $industry_shares_stacked  $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e6nop

********    Panel D: Control for baseline population      ***********

*Column 4: Weighted by population*
reg d_logpop exposure_robots logpop $demographics_stacked_nopop $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e4pop

*Column 5: Excludes zones with highest exposure*
reg d_logpop exposure_robots logpop $demographics_stacked_nopop $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e5pop

*Column 6: Same weight to all czones*
reg d_logpop exposure_robots logpop $demographics_stacked_nopop $industry_shares_stacked  $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e6pop

*Export Panel C - Table A18*
estout e1nop e2nop e3nop e4nop e5nop e6nop using "$project/results/table_population_nop.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 

*Export Panel D - Table A18*
estout e1pop e2pop e3pop e4pop e5pop e6pop using "$project/results/table_population_pop.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots" logpop "\multirow{2}{=}{Log of baseline population}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots logpop) ///
order(exposure_robots logpop) 

