/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A15 : "THE EFFECTS OF ROBOTS ON EMPLOYMENT: ADDITIONAL OUTCOMES "

The table presents estimates of the effects of exposure to robots on several 
labor market outcomes.

- Panel A: Change in log employment
- Panel B: Change in log manufacturing employment
- Panel C: Change in the employment to population ratio, including self-employment
- Panel D: Change in the employment to popualtion ratio, including self-employment 
		   and public employment
- Panel E: Change in the employment to population ratio from the CBP
- Panel F: Change in non-participation rate
- Panel G: Change in unemployment rate		   

5.21.2018 (Revised 4/9/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/* Loop through the different outcomes:

ln_emppriv	: log employment
ln_empman	: log manufacturing employment
_empnpub	: employment to population ratio, including self-employment
_empraw		: employment to population ratio, including self employment and public employment
_cbp_emp_total_imp: employment to population ratio, from CBP
_nonpart	: non-participation rate
_urate		: unemployment rate
*/

foreach depvar in ln_emppriv ln_empman _empnpub _empraw _cbp_emp_total_imp _nonpart _urate{

****** Columns 1 - 3 :  Long differences, 1990 - 2007 *****
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07

* Column 1: Weighted by population
reg d`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1long

* Column 2: Excludes zones with highest exposure
reg d`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2long

* Column 3: Unweighted
reg d`depvar'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3long

****** Columns 4 - 6 :  Stacked differences, 1990 - 2000 and 2000 - 2007 *****
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
xtset czone year, delta(10)
sort czone year

gen exposure_robots=expof_${expomes}

* Column 4: Weighted by population
reg d`depvar' exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e1stack

* Column 5: Excludes zones with highest exposure
reg d`depvar' exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2stack

* Column 6: Unweighted
reg d`depvar' exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e3stack

*Export each panel of table A15 separatedly*
estout e1long e2long e3long e1stack e2stack e3stack  using "$project/results/table_other_outcomes_`depvar'.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 

}
