/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Panels E and F of Table A18 : 
"THE EFFECTS OF ROBOTS ON MIGRATION, POPULATION, AND HOUSING PRICES AND RENTS."

The table presents estimates of the effects of exposure to robots on migration rates
and changes in log population
- Panel E: Change in log house prices.
- Panel F: Change in log monthly rents.

4/9/2019
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

***** Columns 1 -3 : Long Differences, 1990 - 2007 *****
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07

********************************************************************************
**			Panel E - Long differences:  Change in log house prices			  **
********************************************************************************

* Column 1: Weighted by population
reg d_hpi_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1_longdif_hpi

* Column 2: Excludes zones with highest exposure
reg d_hpi_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2_longdif_hpi

* Column 3: Unweighted
reg d_hpi_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3_longdif_hpi

********************************************************************************
**			Panel F - Long differences: Change in log monthly rents		   	  **
********************************************************************************

* Column 1: Weighted by population
reg d_rents_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1_longdif_rent

* Column 2: Excludes zones with highest exposure
reg d_rents_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2_longdif_rent

* Column 3: Unweighted
reg d_rents_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3_longdif_rent


***** Columns 4 - 6 : Stacked Differences, 1990 - 2000 and 2000 - 2007 *****
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate

* Set panel structure for stacked differences analysis
xtset czone year, delta(10)
sort czone year

gen exposure_robots=expof_${expomes}

********************************************************************************
**			Panel E. Stacked differences: Change in log house prices	      **
********************************************************************************

* Column 4: Weighted by population
reg d_hpi exposure_robots  $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e1_stacked_hpi

* Column 5: Excludes zones with highest exposure
reg d_hpi exposure_robots  $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2_stacked_hpi

* Column 6: Unweighted
reg d_hpi exposure_robots  $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e3_stacked_hpi


********************************************************************************
**			Panel F. Stacked Differences: Change in log monthly rents	      **
********************************************************************************

* Column 4: Weighted by population
reg d_rents exposure_robots  $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e1_stacked_rent

* Column 5: Excludes zones with highest exposure
reg d_rents exposure_robots  $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2_stacked_rent

* Column 6: Unweighted
reg d_rents exposure_robots  $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year , r cluster(state)
estimates store e3_stacked_rent


* Export Table A18, Panel E *
estout e1_longdif_hpi e2_longdif_hpi e3_longdif_hpi e1_stacked_hpi e2_stacked_hpi e3_stacked_hpi using "$project/results/table_houses.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots" chinashock_iv "Chinese imports") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots)


* Export Table A18, Panel F *
estout e1_longdif_rent e2_longdif_rent e3_longdif_rent e1_stacked_rent e2_stacked_rent e3_stacked_rent using "$project/results/table_rents.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots" chinashock_iv_90_07 "Chinese imports") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots)

