/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A14 : "THE EFFECT OF ROBOTS ON MANUFACTURING EMPLOYMENT"

The table presents estimates of the effects of exposure to robots on the manufacturing
employment to population ratio.
- Panel A: All workers in manufacturing
- Panel B: Male workers in manufacturing
- Panel C: Female workers in manufacturing
- Panel D: Workers with no college degree in manufacturing
- Panel E: Workers with college degree or more in manufacturing
			
 
5.21.2018 (Revised 4/9/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

********************************************************************************
*** Panel A: Change in the Employment to Population ratio					****
*** All workers in manufacturing											****
********************************************************************************

***** Columns 1 - 4 : Long Differences, 1990 - 2007 *****
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07

* Column 1 : Weighted by population
reg d_empman_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1long

* Column 2 : Excludes zones with highest Exposures 
reg d_empman_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2long

* Column 3 : Unweighted
reg d_empman_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3long

* Column 4 : Control for exposure to robots in automotive industry
reg d_empman_1990_2008 exposure_robots expoc_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects  [w=ipums_pop_1990], r cluster(state)
estimates store e4long

***** Columns 5 - 8 : Stacked Differences, 1990 - 2000 and 2000 - 2007 *****
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
xtset czone year, delta(10)
sort czone year

gen exposure_robots=expof_${expomes}

* Column 5 : Weighted by population
reg d_empman exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e1stack

* Column 6 : Excludes zones with highest Exposures 
reg d_empman exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2stack

* Column 7 : Unweighted
reg d_empman exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e3stack

* Column 8 : Control for exposure to robots in automotive industry
reg d_empman  exposure_robots expoc_${expomes} $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990]  , r cluster(state)
estimates store e4stack

*Export Panel A, Table A14*
estout e1long e2long e3long e4long  e1stack e2stack e3stack e4stack  using "$project/results/table_manufacturing_emp.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots)

**********************************************
********************************************************************************
*** 		Change in the Employment to Population ratio					****
*** Panel B: Male Workers in Manufacturing									****
*** Panel C: Female Workers in Manufacturing								****
*** Panel D: Workers with no college degree working in Manufacturing		****
*** Panel E: Workers with college degree or more working in Manufacturing	****
********************************************************************************

*Loop through dependent variables for different subgroups
foreach var in unc_m unc_f unc_low unc_high {

***** Columns 1 - 4 : Long Differences, 1990 - 2007 *****
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07

* Column 1 : Weighted by population
reg d_empman_`var'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1long

* Column 2 : Excludes zones with highest Exposures 
reg d_empman_`var'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2long

* Column 3 : Unweighted
reg d_empman_`var'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3long

* Column 4 : Control for exposure to robots in automotive industry
reg d_empman_`var'_1990_2008 exposure_robots expoc_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects  [w=ipums_pop_1990], r cluster(state)
estimates store e4long

***** Columns 5 - 8 : Stacked Differences, 1990 - 2000 and 2000 - 2007 *****
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
xtset czone year, delta(10)
sort czone year

gen exposure_robots=expof_${expomes}

* Column 5 : Weighted by population
reg d_empman_`var' exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e1stack

* Column 6 : Excludes zones with highest Exposures 
reg d_empman_`var' exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2stack

* Column 7 : Unweighted
reg d_empman_`var' exposure_robots $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e3stack

* Column 8 : Control for exposure to robots in automotive industry
reg d_empman_`var'  exposure_robots expoc_${expomes} $demographics_stacked $industry_shares_stacked  $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990]  , r cluster(state)
estimates store e4stack

*Export each Panel of Table A14 separatedly*
estout e1long e2long e3long e4long  e1stack e2stack e3stack e4stack  using "$project/results/table_manufacturing_emp_`var'.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots)


}
