/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Figure 8  - Panel A: "THE EFFECTS OF ROBOTS ON INDUSTRIES AND OCCUPATIONS" 
					 Changes in employment by industry 
					 (Long differences, Long differences for highest exposure zones,
					 Stacked differences)
					 
Figure A4 - Panel A: "THE EFFECTS OF ROBOTS ON INDUSTRIES AND OCCUPATIONS - ADDITIONAL ESTIMATES"
					 Changes in employment by industry 
					 (Unweighted long differences, Stacked differences excluding
					 highest exposure zones. unweighted stacked differences)	

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

* Create empty dataset which will be populated with the estimates
clear all
set obs 1
gen industry=""
gen baseline_b=.
gen baseline_se=.
gen nohigh_b=.
gen nohigh_se=.
gen unw_b=.
gen unw_se=.
gen stacked_b=.
gen stacked_se=.
gen stacknohigh_b=.
gen stacknohigh_se=.
gen stackunw_b=.
gen stackunw_se=.
save "${project}/results/industry_estimates.dta", replace

* One observation per industry
local current_obs=1
* Loop through the different industries
foreach industry in manufacture highexpo lowexpo agriculture mining transportation construction nont wholesale profserv techservices finance other {

use "${project}/clean_data/outcomes_longdif_czone.dta", replace
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
gen exposure_robots=expof_${expomes}93_07

************** Long Differences *****************

*Long differences: first bar plotted in Figure 8*
reg d_ind_`industry'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
preserve
use "${project}/results/industry_estimates.dta", clear
set obs `current_obs'
replace industry="`industry'" in `current_obs'
replace baseline_b=_b[exposure_robots] in `current_obs'
replace baseline_se=_se[exposure_robots] in `current_obs'
save "${project}/results/industry_estimates.dta", replace
restore

*Long differences excluding highest exposure zone: second bar plotted in Figure 8 *
reg d_ind_`industry'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
preserve
use "${project}/results/industry_estimates.dta", clear
replace nohigh_b=_b[exposure_robots] in `current_obs'
replace nohigh_se=_se[exposure_robots] in `current_obs'
save "${project}/results/industry_estimates.dta", replace
restore

*Long differences - unweighted estimates: First bar plotted in figure A4 *
reg d_ind_`industry'_1990_2008 exposure_robots $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
preserve
use "${project}/results/industry_estimates.dta", clear
replace unw_b=_b[exposure_robots] in `current_obs'
replace unw_se=_se[exposure_robots] in `current_obs'
save "${project}/results/industry_estimates.dta", replace
restore

************ Stacked Differences *****************

*Stacked differences: Third bar plotted in Figure 8*
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate keepusing(ipums_pop_1990)
gen exposure_robots=expof_${expomes}
reg d_ind_`industry' exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
preserve
use "${project}/results/industry_estimates.dta", clear
replace stacked_b=_b[exposure_robots] in `current_obs'
replace stacked_se=_se[exposure_robots] in `current_obs'
save "${project}/results/industry_estimates.dta", replace
restore

*Stacked differences excluding highest exposure zones: Second bar plotted in Figure A4 *
reg d_ind_`industry' exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
preserve
use "${project}/results/industry_estimates.dta", clear
replace stacknohigh_b=_b[exposure_robots] in `current_obs'
replace stacknohigh_se=_se[exposure_robots] in `current_obs'
save "${project}/results/industry_estimates.dta", replace
restore

*Unweighted Stacked differences: Third bar plotted in Figure A4 *
reg d_ind_`industry' exposure_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year, r cluster(state)
preserve
use "${project}/results/industry_estimates.dta", clear
replace stackunw_b=_b[exposure_robots] in `current_obs'
replace stackunw_se=_se[exposure_robots] in `current_obs'
save "${project}/results/industry_estimates.dta", replace
restore

local current_obs=`current_obs'+1
}



**************** Plot Graphs ****************
use "${project}/results/industry_estimates.dta", clear

gen indname=industry

* Position on the x-axis
gen position_1=4*(_n-1)+1
gen position_2=4*(_n-1)+2
gen position_3=4*(_n-1)+3
gen position_n=4*(_n-1)+2
count
local number=r(N)
local max_val=4*(r(N)-1)+2

*Create horizontal bars as base to each triplet of estimates (useful when plotting)
gen zero=0
forvalues j=1(1)`number'{
gen bar`j'=.
replace bar`j'=4*(`j'-1)+0.4 in 1
replace bar`j'=4*(`j'-1)+3.6 in 2
}

* Create confidence bars at 5 % significance
foreach estim in baseline nohigh unw stacked stacknohigh stackunw{
gen low_`estim'=`estim'_b-1.96*`estim'_se
gen high_`estim'=`estim'_b+1.96*`estim'_se
}



* Figure 8, Panel A: "THE EFFECTS OF ROBOTS ON INDUSTRIES - Changes in employment by industry" 
* Long differences, Long differences excluding highest exposure zones, Stacked differences
twoway (bar baseline_b position_1,  barwidth(0.7) fcolor("${main_color}") lcolor(black) lwidth(vthin)) (rcap low_baseline high_baseline position_1, lcolor(black) lwidth(vthin)) ///
	   (bar nohigh_b position_2,  barwidth(0.7) fcolor("${second_color}") lcolor(black) lwidth(vthin)) (rcap low_nohigh high_nohigh position_2, lcolor(black) lwidth(vthin)) ///
	   (bar stacked_b position_3,  barwidth(0.7) fcolor("${third_color}") lcolor(black) lwidth(vthin)) (rcap low_stacked high_stacked position_3, lcolor(black) lwidth(vthin)) ///
	   (line zero bar1, lcolor(black) lwidth(vthin)) ///
	   (line zero bar2, lcolor(black) lwidth(vthin)) ///
	   (line zero bar3, lcolor(black) lwidth(vthin)) ///
	   (line zero bar4, lcolor(black) lwidth(vthin)) ///
	   (line zero bar5, lcolor(black) lwidth(vthin)) ///
	   (line zero bar6, lcolor(black) lwidth(vthin)) ///
	   (line zero bar7, lcolor(black) lwidth(vthin)) ///
	   (line zero bar8, lcolor(black) lwidth(vthin)) ///
	   (line zero bar9, lcolor(black) lwidth(vthin)) ///
	   (line zero bar10, lcolor(black) lwidth(vthin)) ///
	   (line zero bar11, lcolor(black) lwidth(vthin)) ///
	   (line zero bar12, lcolor(black) lwidth(vthin)) ///
	   (line zero bar13, lcolor(black) lwidth(vthin)) ///
       , title("Panel A. Changes in employment by industry", size(small) position(11) color(dknavy)) ytitle("Point estimate for employment rate change", size(small) margin(zero)) ysize(5) xsize(13)  xscale(alt) graphregion(fcolor(white))  ylabel(-0.4(0.1)0.1, labsize(small)) xscale(noline)  ///
	   legend(off) ///
       xlabel(2 `"Manufacturing"' ///
	          6 `""Manufacturing:" "highly exposed""' ///
			  10 `""Manufacturing:" "others""' ///
			  14 `""Agriculture" "and forestry""' ///
			  18 `"Mining"' ///
			  22 `""Transportation" "and" "warehousing"' ///
			  26 `"Construction"' ///
			  30 `""Retail and" "personal services""' ///
			  34 `"Wholesale"' ///
			  38 `""Professional" "services"' ///
			  42 `""Technical" "services"' ///
			  46 `""Finance" "and" "insurance"' ///
			  50 `""Education," "healthcare" "and" "public sector""' ///			  
	   ,   valuelabel labsize(vsmall) noticks) 
graph export "$project/results/figure_heterogeneity_industry.png", as(png) width(3000)  replace



* Figure A4, Panel A: "THE EFFECTS OF ROBOTS ON INDUSTRIES, ADDITIONAL ESTIMATES - Changes in employment by industry" 
* Unweighted long differences, Stacked differences excluding highest exposure zones, Unweighted stacked differences
twoway (bar unw_b position_1,  barwidth(0.7) fcolor("${main_color}") lcolor(black) lwidth(vthin)) (rcap low_unw high_unw position_1, lcolor(black) lwidth(vthin)) ///
	   (bar stacknohigh_b position_2,  barwidth(0.7) fcolor("${second_color}") lcolor(black) lwidth(vthin)) (rcap low_stacknohigh high_stacknohigh position_2, lcolor(black) lwidth(vthin)) ///
	   (bar stackunw_b position_3,  barwidth(0.7) fcolor("${third_color}") lcolor(black) lwidth(vthin)) (rcap low_stackunw high_stackunw position_3, lcolor(black) lwidth(vthin)) ///
	   (line zero bar1, lcolor(black) lwidth(vthin)) ///
	   (line zero bar2, lcolor(black) lwidth(vthin)) ///
	   (line zero bar3, lcolor(black) lwidth(vthin)) ///
	   (line zero bar4, lcolor(black) lwidth(vthin)) ///
	   (line zero bar5, lcolor(black) lwidth(vthin)) ///
	   (line zero bar6, lcolor(black) lwidth(vthin)) ///
	   (line zero bar7, lcolor(black) lwidth(vthin)) ///
	   (line zero bar8, lcolor(black) lwidth(vthin)) ///
	   (line zero bar9, lcolor(black) lwidth(vthin)) ///
	   (line zero bar10, lcolor(black) lwidth(vthin)) ///
	   (line zero bar11, lcolor(black) lwidth(vthin)) ///
	   (line zero bar12, lcolor(black) lwidth(vthin)) ///
	   (line zero bar13, lcolor(black) lwidth(vthin)) ///
       , title("Panel A. Changes in employment by industry", size(small) position(11) color(dknavy))  ytitle("Point estimate for employment rate change", size(small) margin(zero)) ysize(5) xsize(13)  xscale(alt) graphregion(fcolor(white))  ylabel(-0.6(0.2)0.1, labsize(small)) xscale(noline)  ///
	   legend(off) ///
       xlabel(2 `"Manufacturing"' ///
	          6 `""Manufacturing:" "highly exposed""' ///
			  10 `""Manufacturing:" "others""' ///
			  14 `""Agriculture" "and forestry""' ///
			  18 `"Mining"' ///
			  22 `""Transportation" "and" "warehousing"' ///
			  26 `"Construction"' ///
			  30 `""Retail and" "personal services""' ///
			  34 `"Wholesale"' ///
			  38 `""Professional" "services"' ///
			  42 `""Technical" "services"' ///
			  46 `""Finance" "and" "insurance"' ///
			  50 `""Education," "healthcare" "and" "public sector""' ///			  
	   ,   valuelabel labsize(vsmall) noticks) 
graph export "$project/results/figure_heterogeneity_appendix_industry.png", as(png) width(3000)  replace



