/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
- Figure 1 in the main text: Trends of industrial robots in the United States and Europe 1993-2007
- Figure 2 in the main text: Adjusted penetration of robots in the US and Europe by Industry (1993-2007)
- Figure 3 in the main text: Relationship between robots and labor demand across industries (NBER-CES data)

In addition, it creates figures on the relationship between robots and labor demand across
industries using CBP data and also NBER-CES data only for production workers.
These figures are not reported in the paper

5.26.2018 (revised 4/1/2019)
Pascual Restrepo

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */


* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
* * Program to create plots of residuals in stacked differences analysis * * * * 
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
cap program drop resid_plot_stacked
program define resid_plot_stacked, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) xtitle(string) ytitle(string)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	
	quietly: reg `y_vars' `x_var' `controls'  `wt'  `if', r
	tempvar est_sample
	tempvar residual_y
	tempvar projected_y
	quietly: gen `est_sample'=e(sample)
	quietly: predict `residual_y' if `est_sample'==1, resid
	quietly: sum `y_vars' if e(sample) `wt'
	quietly: gen `projected_y'=`residual_y'+r(mean)
	quietly: sum `x_var' if e(sample) `wt'
	quietly: replace `projected_y'=`projected_y'+_b[`x_var']*(`x_var'-r(mean))
	tempvar projected_y_nocar
	quietly: gen `projected_y_nocar'=`projected_y' if industry!="automotive"
		
	*Define set of markers to label*
	tempvar tag_label
	tempvar tag_rank
	quietly: gen `tag_label'=0
	
	*Residuals: identify observations with smallest and biggest residuals*
	quietly: egen `tag_rank'=rank(`residual_y') if `residual_y'!=.
	quietly: sum `residual_y' if `tag_rank'==2
	quietly: replace `tag_label'=1 if `residual_y'<r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`residual_y') if `residual_y'!=.
	quietly: sum `residual_y' if `tag_rank'==2
	quietly: replace `tag_label'=1 if `residual_y'>r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	*Yvar: identify observations with smallest and largest values of dep. variable*
	quietly: egen `tag_rank'=rank(`y_vars') if `residual_y'!=.
	quietly: sum `y_vars' if `tag_rank'==2
	quietly: replace `tag_label'=1 if `y_vars'<r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`y_vars') if `residual_y'!=.
	quietly: sum `y_vars' if `tag_rank'==2
	quietly: replace `tag_label'=1 if `y_vars'>r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	*Xvar: identify observations with smallest and largest values of regressors*
	quietly: egen `tag_rank'=rank(`x_var') if `residual_y'!=.
	quietly: sum `x_var' if `tag_rank'==5
	quietly: replace `tag_label'=1 if `x_var'<r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`x_var') if `residual_y'!=.
	quietly: sum `x_var' if `tag_rank'==5
	quietly: replace `tag_label'=1 if `x_var'>r(mean) & `residual_y'!=.
	quietly: drop `tag_rank'

	*Define label extremes for the x-axis
	quietly: sum `x_var' `if', d
	local min=5*floor(r(min)/5)
	local max=5*floor(r(max)/5)+5
	
	twoway (scatter `projected_y' `x_var' `wt' if period==2& `projected_y'!=., mcolor("${second_color}") msize(medium) msymbol(circle) mlcolor(black) mlwidth(vthin)) ///
		   (scatter `projected_y' `x_var' `wt' if period==1& `projected_y'!=., mcolor("${main_color}") msize(medium) msymbol(circle) mlcolor(black) mlwidth(vthin)) ///
		   (lfit    `projected_y' `x_var' `wt' if `projected_y'!=., range(`min' `max') lcolor(gs4) lwidth(thin)) ///
		   (lfit    `projected_y_nocar' `x_var' `wt' if `projected_y'!=., range(`min' `max') lpattern(dash) lcolor(gs4) lwidth(thin)) ///
		   (scatter `projected_y' `x_var' if `tag_label'==1, mcolor("${second_color}") msize(zero) mlabel(indname) mlabsize(vsmall) mlabcolor(gs8) mlabposition(12) mlabgap(small)), ///
		   legend(off) xtitle("`xtitle'", size(small)) ytitle("`ytitle'", size(small)) ///
		   ysize(5) xsize(8) ylabel(, labsize(small) grid glwidth(thin) glcolor(white)) xlabel(`min'(5)`max', labsize(small) grid glwidth(thin) glcolor(white))  graphregion(fcolor(white) ifcolor(white)  lcolor(white) ilcolor(white)) plotregion(fcolor(white))


end

***********************
*** Figure 1: trends in INDUSTRIAL ROBOTS IN THE UNITED STATES AND EUROPE 1993-2007
***********************
use "${project}/clean_data/country_adoption_trends.dta", clear

tsset year

twoway (scatter rdens_rest year,   msymbol(circle) mcolor("${main_color}") mlcolor(black) lwidth(vthin)) ///
	   (line    rdens_rest year,   lcolor("gs10") lwidth(vthin)) ///
	   (scatter rdens_us year,     msymbol(diamond) mcolor("${second_color}") mlcolor(black) lwidth(vthin)) ///
	   (line    rdens_us year,     lcolor("${second_color}") lwidth(vthin)) ///
	   (scatter rdens_euro5 year,  msymbol(triangle) mcolor("${third_color}") mlcolor(black) lwidth(vthin)) ///
	   (line    rdens_euro5 year,  lcolor("${third_color}") lwidth(vthin)) ///
	   (scatter rdens_ger year,    msymbol(square) mcolor(black) lcolor(black) lwidth(vvthin)) ///
	   (line    rdens_ger year,    lcolor(black) lwidth(vthin)), ///
	   ysize(4) xsize(8) xlabel(1993(2)2014, labsize(small)) ylabel(0(1)5, labsize(small)) xtitle("") ytitle("Stock of robots per thousand of workers in 1993") ///
	   legend(ring(0) pos(10) rows(4) region(lwidth(none) lcolor(none)) order(7 "Germany" 5 "Denmark, Finland, France, Italy and Sweden"  3 "United States" 1 "Norway, Spain, and UK") size(small)) graphregion(fcolor(white)) 
graph export "$project/results/figure_robot_trends.png", as(png) width(3000)   replace


*******************************************************************************************
*** Figure 2: ADJUSTED PENETRATION OF ROBOTS IN THE US AND EUROPE BY INDUSTRY (First Stage) ***
*******************************************************************************************
use "${project}/clean_data/industry_data_ifr19", clear
cap drop change_us change_euro
gen change_us=max(0.002,14*apr_us_adj04_07_/3)
gen change_euro=max(0.002,apr_${indmes}93_07_)

twoway (lfit change_us change_us, range(.0002 200) lwidth(thin) lcolor(gs4)) ///
       (scatter change_us change_euro [fweight = emp_us], mcolor("${main_color}") msize(medium) msymbol(circle) mlcolor(black) mlwidth(vthin)) ///
	   (scatter change_us change_euro, mcolor("${main_color}") msize(zero) mlabel(indname) mlabsize(vsmall) mlabcolor(gs8) mlabposition(11) mlabgap(small)), ///
       legend(off) ytitle(Adjusted penetration of robots in the US 2004-2007, size(small)) xtitle(Adjusted penetration of robots 1993-2007, size(small))  ///
	   ysize(5) xsize(5) yscale(log) xscale(log) ylabel(.002 .02 .2 2 20, labsize(small) grid glwidth(thin) glcolor(white)) xlabel(.002 .02 .2 2 20, labsize(small) grid glwidth(thin) glcolor(white))  graphregion(fcolor(white) ifcolor(white)  lcolor(white) ilcolor(white)) plotregion(fcolor(white) margin(zero))
graph export "$project/results/figure_industry_first_stage.png", as(png) width(3000)   replace


*******************************************************************************************
***RELATIONSHIP BETWEEN ROBOTS AND LABOR DEMAND ACROSS INDUSTRIES (stacked differences) ***
***         Multiple graphs using different data sources: CBP and NBER-CES         ********
*******************************************************************************************

use "${project}/clean_data/industry_data_ifr19", clear
encode industry_ifr, gen(indcode)
expand 2
bys industry_ifr: gen period=_n

*Robot exposure
bys industry_ifr: gen change_robots=apr_${indmes}00_07 if _n==2
bys industry_ifr: replace change_robots=apr_${indmes}93_00 if _n==1
*Chinese exposure
bys industry_ifr: gen change_china=china_sag_iv_1999_2007 if _n==2
bys industry_ifr: replace change_china=china_sag_iv_1991_1999 if _n==1
*industry names*
bys industry_ifr: replace indname=indname+" 1990" if _n==1
bys industry_ifr: replace indname=indname+" 2000" if _n==2

** Change in log EMPLOYMENT: CBP data**
cap drop depvar
gen depvar=.
replace depvar=100*(ln(cbp_emp2007)-ln(cbp_emp2000)) if period==2
replace depvar=100*(ln(cbp_emp2000)-ln(cbp_emp1993)) if period==1

resid_plot_stacked depvar change_robots [w=cbp_emp1993] if manufacturing==1, control(change_china i.period light_manuf manufacturing) xtitle("Adjusted penetration of robots ") ytitle("Change in log employment (CBP)")
graph export "$project/results/figure_industry_emp_cbp.png", as(png) width(3000)  replace

** Change in log WAGE bill: CBP data**
cap drop depvar
gen depvar=.
replace depvar=100*(ln(cbp_real_pay2007)-ln(cbp_real_pay2000)) if period==2
replace depvar=100*(ln(cbp_real_pay2000)-ln(cbp_real_pay1993)) if period==1

resid_plot_stacked depvar change_robots [w=cbp_emp1993] if manufacturing==1, control(change_china i.period light_manuf manufacturing) xtitle("Adjusted penetration of robots ") ytitle("Change in log wage bill (CBP)")
graph export "$project/results/figure_industry_pay_cbp.png", as(png) width(3000)  replace

** Figure 3 - right panel: Change in log EMPLOYMENT, NBER-CES data**
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_emp2007)-ln(nber_emp2000)) if period==2
replace depvar=100*(ln(nber_emp2000)-ln(nber_emp1993)) if period==1

resid_plot_stacked depvar change_robots [w=nber_emp1993], control(change_china i.period light_manuf manufacturing) xtitle("Adjusted penetration of robots ") ytitle("Change in log employment (NBER-CES)")
graph export "$project/results/figure_industry_emp_nber.png", as(png) width(3000)  replace

** Figure 3 - left panel: Change in log WAGE bill, NBER-CES data**
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_pay2007)-ln(nber_pay2000)) if period==2
replace depvar=100*(ln(nber_pay2000)-ln(nber_pay1993)) if period==1

resid_plot_stacked depvar change_robots [w=nber_emp1993], control(change_china i.period light_manuf manufacturing) xtitle("Adjusted penetration of robots") ytitle("Change in log wage bill (NBER-CES)")
graph export "$project/results/figure_industry_pay_nber.png", as(png) width(3000)  replace

**Change in log EMPLOYMENT of production workers - NBER-CES data**
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_prode2007)-ln(nber_prode2000)) if period==2
replace depvar=100*(ln(nber_prode2000)-ln(nber_prode1993)) if period==1

resid_plot_stacked depvar change_robots [w=nber_emp1993], control(change_china i.period light_manuf manufacturing) xtitle("Adjusted penetration of robots") ytitle("Change in log production workers (NBER-CES)")
graph export "$project/results/figure_industry_prode_nber.png", as(png) width(3000)  replace

**Change in log WAGE bill of production workers - NBER-CES data**
cap drop depvar
gen depvar=.
replace depvar=100*(ln(nber_payblue2007)-ln(nber_payblue2000)) if period==2
replace depvar=100*(ln(nber_payblue2000)-ln(nber_payblue1993)) if period==1

resid_plot_stacked depvar change_robots [w=nber_emp1993], control(change_china i.period light_manuf manufacturing) xtitle("Adjusted penetration of robots") ytitle("Change in log production wage bill (NBER-CES)")
graph export "$project/results/figure_industry_payblue_nber.png", as(png) width(3000)  replace

