/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Figure 10 : "EFFECTS OF ROBOTS ON EMPLOYMENT ON THE WAGE DISTRIBUTION"
- Panel A: All workers
- Panel B: Workers with no college degree
- Panel C: Workers with college degree
- Panel D: Men
- Panel E: Women

5.26.2018 (Revised 4/19/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

* Loop over the different groups: all workers, workers with college degree,
* 								  workers with no college degree, men, women
foreach class in  all high low all_m all_f{

* Create empty dataset for graph to be populated by estimates
clear all
set obs 19
gen quantile=5*_n if _n<=19
gen quantile_b=.
gen quantile_se=.
gen average_b=.
gen average_se=.
save "${project}/results/quantile_estimates_`class'.dta", replace

*Long differences*
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07

* Quantile estimates
forvalues perc=5(5)95{
* Adjust the dependent variable to 15 years difference to make it consistent with the exposure-robots measure (1993-2007)
gen change_p`perc'=0.7*100*(cat_p`perc'wage_`class'_2000-cat_p`perc'wage_`class'_1990)+100*(cat_p`perc'wage_`class'_2008-cat_p`perc'wage_`class'_2000)

reg change_p`perc' exposure_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)

preserve
use "${project}/results/quantile_estimates_`class'.dta", clear
replace quantile_b=_b[exposure_robots] if quantile==`perc'
replace quantile_se=_se[exposure_robots] if quantile==`perc'
save "${project}/results/quantile_estimates_`class'.dta", replace
restore
}

use "${project}/results/quantile_estimates_`class'.dta", clear

* Create estimates for extremes of confidence interval
sort quantile
gen min_b=quantile_b-1.96*quantile_se
gen max_b=quantile_b+1.96*quantile_se

gen min_ave_b=average_b-1.96*average_se
gen max_ave_b=average_b+1.96*average_se

* Generate titles for the different panels of the figure
if "`class'"=="all"{
local title "Panel A. All workers"
}
else if "`class'"=="high"{
local title "Panel C. Workers with college degree"
}
else if "`class'"=="low"{
local title "Panel B. Workers with no college degree"
}
else if "`class'"=="all_m"{
local title "Panel D. Men"
}
else if "`class'"=="all_f"{
local title "Panel E. Women"
}

twoway (connected quantile_b quantile, lcolor(maroon) mcolor(maroon) msize(medsmall)) (line min_b quantile, lcolor(gs8) lpattern(dash)) (line max_b quantile, lcolor(gs8) lpattern(dash)), ///
       yline(0, lwidth(vthin) lcolor(navy)) title("`title'", position(11) color(dknavy)) xlabel(5(10)95)  graphregion(fcolor(white)) xtitle("Quantile") ytitle(Estimate) ylabel(-1.5(.5)1.5) legend(rows(1) region(lwidth(none) lcolor(none)) order(1 "Point estimate for quantile"))
graph export "$project/results/figure_quantile_`class'.png", as(png) width(3000)  replace


}
