/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table 2  : "THE EFFECTS OF ROBOTS ON EMPLOYMENT AND WAGES: LONG DIFFERENCES"
Table A31: "ALTERNATIVE INFERENCE FOLLOEING BORUSYAK ET AL. (2018): LONG DIFFERENCES"

The tables present estimates of the effects of exposure to robots on employment
and wages.

Warning: Estimates using Brousyak et al. procedure for changes in log wage (Table A31, panel B)
		 may take some time to process.

5.21.2018 (revised 4/29/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

*******************************************************
**Program to do inference a-la Borusyak et al. (2018)**
*******************************************************
cap program drop inference_bjh
program define inference_bjh, eclass

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv)]

		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
		
		* Parse varlist into y-vars and x-var
		local x_var=word("`varlist'",-1)
		local y_var=regexr("`varlist'"," `x_var'$","")

/* We convert the dataset using the IV exposure to robots (shift-share) into a new dataset
of weighted shock-level aggregates, as described in Borusyak, Hull, and Jaravel (2018).*/
preserve
ssaggregate `y_var' `x_var' `wt'  `if', n(ind_id) s(share_ind)  controls("`controls'") 
gen industry_ifr19=""
replace industry_ifr19="agriculture" if ind_id==1
replace industry_ifr19="automotive" if ind_id==2
replace industry_ifr19="construction" if ind_id==3
replace industry_ifr19="electronics" if ind_id==4
replace industry_ifr19="food" if ind_id==5
replace industry_ifr19="furniture" if ind_id==6
replace industry_ifr19="manufacturing_other" if ind_id==7
replace industry_ifr19="metal_basic" if ind_id==8
replace industry_ifr19="metal_machinery" if ind_id==9
replace industry_ifr19="metal_products" if ind_id==10
replace industry_ifr19="mineral" if ind_id==11
replace industry_ifr19="mining" if ind_id==12
replace industry_ifr19="paper" if ind_id==13
replace industry_ifr19="petrochemicals" if ind_id==14
replace industry_ifr19="research" if ind_id==15
replace industry_ifr19="services" if ind_id==16
replace industry_ifr19="textiles" if ind_id==17
replace industry_ifr19="utilities" if ind_id==18
replace industry_ifr19="vehicles_other" if ind_id==19
* Merge the shift-share shocks using the industry_ifr as identifier (it coincides with ind_id, used in  ssaggregate
merge 1:1 industry_ifr19 using "${project}/clean_data/apr_measures_ifr19.dta" , assert(3) nogenerate
ivreg2 `y_var' (`x_var'=apr_${indmes}93_07) [w=s_n], r
restore

end

********************************************************************************
*** Panel A: Change in the Employment to Population ratio, 1990 - 2007		 ***
********************************************************************************

use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

if ${inference_bjh}==1{
merge 1:1 czone using "${project}/clean_data/czone_shares_ifr19.dta", assert(3) nogenerate
rename (share_ind_agriculture share_ind_automotive share_ind_construction share_ind_electronics share_ind_food share_ind_furniture share_ind_manufacturing_other share_ind_metal_basic share_ind_metal_machinery share_ind_metal_products share_ind_mineral share_ind_mining share_ind_paper share_ind_petrochemicals share_ind_research share_ind_services share_ind_textiles share_ind_utilities share_ind_vehicles_other) ///
       (share_ind1 share_ind2 share_ind3 share_ind4 share_ind5 share_ind6 share_ind7 share_ind8 share_ind9 share_ind10 share_ind11 share_ind12 share_ind13 share_ind14 share_ind15 share_ind16 share_ind17 share_ind18 share_ind19)
}

******	Census division dummies *****
*Table 2 Column 1:
reg d_emppriv_1990_2008 expof_${expomes}93_07 $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1

*Inference a-la BJH: Table A31 Column 1*
if ${inference_bjh}==1{
quietly: inference_bjh d_emppriv_1990_2008 expof_${expomes}93_07 [w=ipums_pop_1990], controls($region_effects)
ereturn display
estimates store e1_bjh
}


***** Census division dummies + Demographics *****
*Table 2 Column 2:
reg d_emppriv_1990_2008 expof_${expomes}93_07 $demographics $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e2

*Inference a-la BJH: Table A31 Column 2*
if ${inference_bjh}==1{
quietly: inference_bjh d_emppriv_1990_2008 expof_${expomes}93_07 [w=ipums_pop_1990], controls($demographics $region_effects)
ereturn display
estimates store e2_bjh
}


***** Census division dummies + Demographics + Industry shares *****
*Table 2 Column 3:
reg d_emppriv_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e3

*Inference a-la BJH: Table A31 Column 3*
if ${inference_bjh}==1{
quietly: inference_bjh d_emppriv_1990_2008 expof_${expomes}93_07 [w=ipums_pop_1990], controls($demographics $industry_shares $region_effects)
ereturn display
estimates store e3_bjh
}


***** Census division dummies + Demographics + Industry Shares + China and Routine jobs *****
*Table 2 Column 4:
reg d_emppriv_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e4

*Inference a-la BJH: Table A31 Column 4*
if ${inference_bjh}==1{
quietly: inference_bjh d_emppriv_1990_2008 expof_${expomes}93_07 [w=ipums_pop_1990], controls($demographics $industry_shares $other_shocks $region_effects)
ereturn display
estimates store e4_bjh
}


***** 	Exclude zones with the highest exposure  	****************************
*Table 2 Column 5:
reg d_emppriv_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e5

*Inference a-la BJH: Table A31 Column 5*
if ${inference_bjh}==1{
quietly: inference_bjh d_emppriv_1990_2008 expof_${expomes}93_07 [w=ipums_pop_1990] if tag_exposure==1, controls($demographics $industry_shares $other_shocks $region_effects)
ereturn display
estimates store e5_bjh
}


***** 			Unweighted							 ***************************
*Table 2 Column 6:
reg d_emppriv_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e6

*Inference a-la BJH: Table A31 Column 6*
if ${inference_bjh}==1{
quietly: inference_bjh d_emppriv_1990_2008 expof_${expomes}93_07, controls($demographics $industry_shares $other_shocks $region_effects)
ereturn display
estimates store e6_bjh
}

*Export Table 2, Panel A*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table2_emppriv.tex", style(tex) ///
varlabels(expof_${expomes}93_07 "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_07) ///
order(expof_${expomes}93_07) 

*Export table A31, Panel A*
if ${inference_bjh}==1{
estout e1_bjh e2_bjh e3_bjh e4_bjh e5_bjh e6_bjh  using "$project/results/table2_inference_bjh_emppriv.tex", style(tex) ///
varlabels(expof_${expomes}93_07 "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_07) ///
order(expof_${expomes}93_07) 
}

********************************************************************************
*** Panel B: Change in the Log Hourly Wages, 1990 - 2007					 ***
********************************************************************************
set more off
use czone d_hrwage_ln_1990_2008 nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_${expomes}93_07 $other_shocks )
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

if ${inference_bjh}==1{
merge m:1 czone using "${project}/clean_data/czone_shares_ifr19.dta", assert(3) nogenerate
rename (share_ind_agriculture share_ind_automotive share_ind_construction share_ind_electronics share_ind_food share_ind_furniture share_ind_manufacturing_other share_ind_metal_basic share_ind_metal_machinery share_ind_metal_products share_ind_mineral share_ind_mining share_ind_paper share_ind_petrochemicals share_ind_research share_ind_services share_ind_textiles share_ind_utilities share_ind_vehicles_other) ///
       (share_ind1 share_ind2 share_ind3 share_ind4 share_ind5 share_ind6 share_ind7 share_ind8 share_ind9 share_ind10 share_ind11 share_ind12 share_ind13 share_ind14 share_ind15 share_ind16 share_ind17 share_ind18 share_ind19)
}
	   
encode state, gen(stcode)
encode group, gen(group_id)

******	Census division dummies *****
*Table 2 Column 1:

reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e1

*Inference a-la BJH: Table A31 Column 1*
if ${inference_bjh}==1{
set matsize 5000
quietly: inference_bjh d_hrwage_ln_1990_2008 expof_${expomes}93_07 [w=wage_earners_1990], controls($region_effects i.group_id)
ereturn display
estimates store e1_bjh
}


***** Census division dummies + Demographics *****
*Table 2 Column 2:
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 $demographics $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e2

*Inference a-la BJH: Table A31 Column 2*
if ${inference_bjh}==1{
set matsize 5000
quietly: inference_bjh d_hrwage_ln_1990_2008 expof_${expomes}93_07 [w=wage_earners_1990], controls($region_effects $demographics  i.group_id)
ereturn display
estimates store e2_bjh
}


***** Census division dummies + Demographics + Industry shares *****
*Table 2 Column 3:
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e3
*Inference a-la BJH: Table A31 Column 3*
if ${inference_bjh}==1{
set matsize 5000
quietly: inference_bjh d_hrwage_ln_1990_2008 expof_${expomes}93_07 [w=wage_earners_1990], controls($region_effects $demographics $industry_shares  i.group_id)
ereturn display
estimates store e3_bjh
}


***** Census division dummies + Demographics + Industry Shares + China and Routine jobs *****
*Table 2 Column 4:
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e4

*Inference a-la BJH: Table A31 Column 4*
if ${inference_bjh}==1{
set matsize 5000
quietly: inference_bjh d_hrwage_ln_1990_2008 expof_${expomes}93_07 [w=wage_earners_1990], controls($region_effects $demographics $industry_shares  $other_shocks  i.group_id)
ereturn display
estimates store e4_bjh
}


***** 	Exclude zones with the highest exposure  		************************
*Table 2 Column 5:
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if tag_exposure==1, absorb(group_id) cluster(stcode)
estimates store e5
*Inference a-la BJH: Table A31 Column 5*
if ${inference_bjh}==1{
set matsize 5000
quietly: inference_bjh d_hrwage_ln_1990_2008 expof_${expomes}93_07 [w=wage_earners_1990] if tag_exposure==1, controls($region_effects $demographics $industry_shares  $other_shocks  i.group_id)
ereturn display
estimates store e5_bjh
}


*****  Unweighted		 *******************************************************
*Table 2 Column 6:
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=nat_earners_weight_1990], absorb(group_id) cluster(stcode)
estimates store e6
*Inference a-la BJH: Table A31 Column 6*
if ${inference_bjh}==1{
set matsize 5000
quietly: inference_bjh d_hrwage_ln_1990_2008 expof_${expomes}93_07 [w=nat_earners_weight_1990], controls($region_effects $demographics $industry_shares  $other_shocks  i.group_id)
ereturn display
estimates store e6_bjh
}

*Export table 2, Panel B*
estout e1 e2 e3 e4 e5 e6  using "$project/results/table2_hrwage_ln.tex", style(tex) ///
varlabels(expof_${expomes}93_07 "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_07) ///
order(expof_${expomes}93_07) 

*Export table A31, Panel B*
if ${inference_bjh}==1{
estout e1_bjh e2_bjh e3_bjh e4_bjh e5_bjh e6_bjh  using "$project/results/table2_inference_bjh_hrwage_ln.tex", style(tex) ///
varlabels(expof_${expomes}93_07 "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_07) ///
order(expof_${expomes}93_07) 
}


